Skip to contents

Provides a textual summary of a group sequential design for negative binomial outcomes, similar to the summary provided by gsDesign::gsDesign(). For tabular output, use gsDesign::gsBoundSummary() directly on the gsNB object.

Usage

# S3 method for class 'gsNB'
summary(object, ...)

Arguments

object

An object of class gsNB.

...

Additional arguments (currently ignored).

Value

A character string summarizing the design (invisibly). The summary is also printed to the console.

Examples

nb_ss <- sample_size_nbinom(
  lambda1 = 0.5, lambda2 = 0.3, dispersion = 0.1, power = 0.9,
  accrual_rate = 10, accrual_duration = 20, trial_duration = 24
)
gs_design <- gsNBCalendar(nb_ss, k = 3)
summary(gs_design)
#> Asymmetric two-sided with non-binding futility bound group sequential design
#> for negative binomial outcomes, 3 analyses, total sample size 53.5, 90 percent
#> power, 2.5 percent (1-sided) Type I error. Control rate 0.5000, treatment rate
#> 0.3000, risk ratio 0.6000, dispersion 0.1000. Accrual duration 20.0, trial
#> duration 24.0, average exposure 14.00. Randomization ratio 1:1. Upper spending:
#> Hwang-Shih-DeCani (gamma = -4) Lower spending: Hwang-Shih-DeCani (gamma = -2)
#> 

# For tabular bounds summary, use gsBoundSummary directly:
# gsDesign::gsBoundSummary(gs_design)