Learn R Programming

gsDesignNB (version 0.2.6)

summary.gsNB: Summary for gsNB objects

Description

Provides a textual summary of a group sequential design for negative binomial outcomes, similar to the summary provided by gsDesign::gsDesign(). For tabular output, use gsDesign::gsBoundSummary() directly on the gsNB object.

Usage

# S3 method for gsNB
summary(object, ...)

Value

A character string summarizing the design (invisibly). The summary is also printed to the console.

Arguments

object

An object of class gsNB.

...

Additional arguments (currently ignored).

Examples

Run this code
nb_ss <- sample_size_nbinom(
  lambda1 = 0.5, lambda2 = 0.3, dispersion = 0.1, power = 0.9,
  accrual_rate = 10, accrual_duration = 20, trial_duration = 24
)
gs_design <- gsNBCalendar(nb_ss, k = 3, analysis_times = c(12, 18, 24))
summary(gs_design)

# For tabular bounds summary, use gsBoundSummary() directly:
gsBoundSummary(gs_design)

Run the code above in your browser using DataLab