Learn R Programming

gsDesignNB (version 0.2.6)

summary.sample_size_nbinom_result: Summary for sample_size_nbinom_result objects

Description

Provides a textual summary of the sample size calculation for negative binomial outcomes, similar to the summary for gsNB objects.

Usage

# S3 method for sample_size_nbinom_result
summary(object, ...)

Value

A character string summarizing the design (invisibly). The summary is also printed to the console.

Arguments

object

An object of class sample_size_nbinom_result.

...

Additional arguments (currently ignored).

Examples

Run this code
x <- sample_size_nbinom(
  lambda1 = 0.5, lambda2 = 0.3, dispersion = 0.1, power = 0.8,
  accrual_rate = 10, accrual_duration = 20, trial_duration = 24
)
class(x)
summary(x)

Run the code above in your browser using DataLab