powered by
Provides a textual summary of the sample size calculation for negative binomial outcomes, similar to the summary for gsNB objects.
# S3 method for sample_size_nbinom_result summary(object, ...)
A character string summarizing the design (invisibly). The summary is also printed to the console.
An object of class sample_size_nbinom_result.
sample_size_nbinom_result
Additional arguments (currently ignored).
x <- sample_size_nbinom( lambda1 = 0.5, lambda2 = 0.3, dispersion = 0.1, power = 0.8, accrual_rate = 10, accrual_duration = 20, trial_duration = 24 ) class(x) summary(x)
Run the code above in your browser using DataLab